@@ -18,13 +18,13 @@ except ImportError:
     import moves
     import server
 
-VERSION = '0.0.24'
+VERSION = '0.0.25'
 
 class Ansi:
     """ The terminal ansi chars """
 
     GREEN = '\033[32m'
-    RED = '\033[31m'
+    RED = '\033[1;31m'
     RESET = '\033[0m'
     GRAY = '\033[37m'
     CYAN = '\033[96m'
